@@ -1,14 +1,12 @@
-
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-
 from node.myownp2pn import mynode
-from node.unl import get_unl_nodes, get_as_node_type
+from node.unl import get_as_node_type
+from node.unl import get_unl_nodes
 
 
 def PropagatingtheTX(tx):
@@ -25,7 +23,7 @@ def PropagatingtheTX(tx):
         "data": tx.data,
         "amount": tx.amount,
         "transaction_fee": tx.transaction_fee,
-        "transaction_time":tx.time
+        "transaction_time": tx.transaction_time,
     }
     for each_node in get_as_node_type(get_unl_nodes()):
-        mynode.main_node.send_data_to_node(each_node, items)
\ No newline at end of file
+        mynode.main_node.send_data_to_node(each_node, items)
